@@ -64,44 +64,127 @@ bitflags! {
         /// `MAP_SHARED`
         const SHARED = libc::MAP_SHARED;
         /// `MAP_SHARED_VALIDATE`
-        #[cfg(not(any(target_os = "android", target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "emscripten", target_os = "fuchsia", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "android",
+            target_os = "emscripten",
+            target_os = "freebsd",
+            target_os = "fuchsia",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "redox",
+        )))]
         const SHARED_VALIDATE = libc::MAP_SHARED_VALIDATE;
         /// `MAP_PRIVATE`
         const PRIVATE = libc::MAP_PRIVATE;
         /// `MAP_ANONYMOUS`, aka `MAP_ANON`
         const ANONYMOUS = libc::MAP_ANONYMOUS;
         /// `MAP_DENYWRITE`
-        #[cfg(not(any(target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "freebsd",
+            target_os = "redox"
+        )))]
         const DENYWRITE = libc::MAP_DENYWRITE;
         /// `MAP_FIXED`
-        #[cfg(not(any(target_os = "android", target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "emscripten", target_os = "fuchsia", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "android",
+            target_os = "emscripten",
+            target_os = "freebsd",
+            target_os = "fuchsia",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "redox",
+        )))]
         const FIXED_NOREPLACE = libc::MAP_FIXED_NOREPLACE;
         /// `MAP_GROWSDOWN`
         #[cfg(not(any(target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "redox")))]
         const GROWSDOWN = libc::MAP_GROWSDOWN;
         /// `MAP_HUGETLB`
-        #[cfg(not(any(target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "freebsd",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "redox",
+        )))]
         const HUGETLB = libc::MAP_HUGETLB;
         /// `MAP_HUGE_2MB`
-        #[cfg(not(any(target_os = "android", target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "emscripten", target_os = "fuchsia", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "android",
+            target_os = "emscripten",
+            target_os = "freebsd",
+            target_os = "fuchsia",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "redox",
+        )))]
         const HUGE_2MB = libc::MAP_HUGE_2MB;
         /// `MAP_HUGE_1GB`
-        #[cfg(not(any(target_os = "android", target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "emscripten", target_os = "fuchsia", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "android",
+            target_os = "emscripten",
+            target_os = "freebsd",
+            target_os = "fuchsia",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "redox",
+        )))]
         const HUGE_1GB = libc::MAP_HUGE_1GB;
         /// `MAP_LOCKED`
-        #[cfg(not(any(target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "freebsd",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "redox",
+        )))]
         const LOCKED = libc::MAP_LOCKED;
         /// `MAP_NORESERVE`
         #[cfg(not(any(target_os = "freebsd", target_os = "redox")))]
         const NORESERVE = libc::MAP_NORESERVE;
         /// `MAP_POPULATE`
-        #[cfg(not(any(target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "freebsd",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "redox",
+        )))]
         const POPULATE = libc::MAP_POPULATE;
         /// `MAP_STACK`
-        #[cfg(not(any(target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "redox",
+        )))]
         const STACK = libc::MAP_STACK;
         /// `MAP_SYNC`
-        #[cfg(not(any(target_os = "android", target_os = "netbsd", target_os = "ios", target_os = "macos", target_os = "freebsd", target_os = "emscripten", target_os = "fuchsia", target_os = "redox")))]
+        #[cfg(not(any(
+            target_os = "android",
+            target_os = "emscripten",
+            target_os = "freebsd",
+            target_os = "fuchsia",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "netbsd",
+            target_os = "openbsd",
+            target_os = "redox",
+        )))]
         const SYNC = libc::MAP_SYNC;
         /// `MAP_UNINITIALIZED`
         #[cfg(any())]
@@ -118,7 +201,7 @@ bitflags! {
         /// `O_CLOEXEC`
         const CLOEXEC = libc::O_CLOEXEC;
         /// `O_DIRECT`
-        #[cfg(not(any(target_os = "redox")))]
+        #[cfg(not(any(target_os = "openbsd", target_os = "redox")))]
         const DIRECT = libc::O_DIRECT;
         /// `O_NONBLOCK`
         const NONBLOCK = libc::O_NONBLOCK;
